@@ -11,6 +11,7 @@ class Connection(EventEmitter):
         self.url = url
         self.state: ConnectionState = 'disconnected'
         self.sio: Optional[socketio.Client] = None
+        self.socket_id: Optional[str] = None
         self._reconnect_timer: Optional[threading.Timer] = None
 
     def connect(self) -> None:
@@ -34,6 +35,8 @@ class Connection(EventEmitter):
         @self.sio.event
         def connect():
             self.state = 'connected'
+            # Store socket_id for auth
+            self.socket_id = self.sio.sid if self.sio else None
             self.emit('connected')
 
         @self.sio.event
