@@ -1,5 +1,6 @@
 from typing import Dict, Optional, Callable
 import json
+import requests
 from .connection import Connection
 from .channel import Channel
 from .types import RealtimeXOptions
@@ -45,9 +46,6 @@ class RealtimeX:
         data = {'channel': channel_name}
         
         if self._is_private_channel(channel_name):
-            if not self.auth_callback:
-                raise ValueError(f"Cannot subscribe to {channel_name}: auth_callback is required for private/presence channels")
-            
             auth_data = self._get_auth_data(channel_name)
             data.update(auth_data)
         
@@ -58,11 +56,44 @@ class RealtimeX:
         return channel_name.startswith('private-') or channel_name.startswith('presence-')
 
     def _get_auth_data(self, channel_name: str) -> Dict:
-        """Get auth data from callback."""
+        """Get auth data from callback or HTTP endpoint."""
         socket_id = self.connection.socket_id or ''
-        auth_result = self.auth_callback(channel_name, socket_id)
         
+        # Use custom auth_callback if provided
+        if self.auth_callback:
+            auth_result = self.auth_callback(channel_name, socket_id)
+            return self._process_auth_result(auth_result, channel_name)
+        
+        # Use auth_endpoint if provided
+        auth_endpoint = self.options.get('auth_endpoint')
+        if auth_endpoint:
+            auth_result = self._request_auth(auth_endpoint, channel_name, socket_id)
+            return self._process_auth_result(auth_result, channel_name)
+        
+        # No auth method provided
+        raise ValueError(f"Cannot subscribe to {channel_name}: auth_callback or auth_endpoint is required for private/presence channels")
+
+    def _request_auth(self, endpoint: str, channel_name: str, socket_id: str) -> Dict:
+        """Make HTTP request to auth endpoint."""
+        try:
+            response = requests.post(endpoint, json={
+                'socket_id': socket_id,
+                'channel_name': channel_name
+            }, headers={
+                'Authorization': f'Bearer {self.api_key}'
+            }, timeout=5)
+            
+            if response.status_code == 200:
+                return response.json()
+            else:
+                return {'auth': ''}
+        except Exception:
+            return {'auth': ''}
+
+    def _process_auth_result(self, auth_result, channel_name: str) -> Dict:
+        """Process auth result from callback or HTTP."""
         auth_data = {}
+        
         if isinstance(auth_result, dict):
             auth_data['auth'] = auth_result.get('auth')
             if 'channel_data' in auth_result:
@@ -96,7 +127,8 @@ class RealtimeX:
             'cluster': 'eu',
             'ws_host': 'ws.realtimex.net',
             'ws_port': 443,
-            'encrypted': True
+            'encrypted': True,
+            'auth_endpoint': None  # Optional HTTP endpoint for auth
         }
         return {**defaults, **options}
 
